@@ -3,6 +3,7 @@ from os.path import exists
 
 import pkg_resources
 import six
+from tqdm.auto import tqdm
 
 if six.PY2:
     from urllib import urlretrieve
@@ -24,15 +25,14 @@ from .openjtalk import OpenJTalk
 OPEN_JTALK_DICT_DIR = os.environ.get(
     "OPEN_JTALK_DICT_DIR",
     pkg_resources.resource_filename(__name__, "open_jtalk_dic_utf_8-1.11"),
-).encode("ascii")
-_DICT_URL = (
-    "https://downloads.sourceforge.net/open-jtalk/open_jtalk_dic_utf_8-1.11.tar.gz"
-)
+).encode("utf-8")
+_dict_download_url = "https://github.com/r9y9/open_jtalk/releases/download/v1.11.1"
+_DICT_URL = f"{_dict_download_url}/open_jtalk_dic_utf_8-1.11.tar.gz"
 
 # Default mei_normal.voice for HMM-based TTS
 DEFAULT_HTS_VOICE = pkg_resources.resource_filename(
     __name__, "htsvoice/mei_normal.htsvoice"
-).encode("ascii")
+).encode("utf-8")
 
 # Global instance of OpenJTalk
 _global_jtalk = None
@@ -41,17 +41,33 @@ _global_jtalk = None
 _global_htsengine = None
 
 
+# https://github.com/tqdm/tqdm#hooks-and-callbacks
+class _TqdmUpTo(tqdm):  # type: ignore
+    def update_to(self, b=1, bsize=1, tsize=None):
+        if tsize is not None:
+            self.total = tsize
+        return self.update(b * bsize - self.n)
+
+
 def _extract_dic():
     global OPEN_JTALK_DICT_DIR
     filename = pkg_resources.resource_filename(__name__, "dic.tar.gz")
     print('Downloading: "{}"'.format(_DICT_URL))
-    urlretrieve(_DICT_URL, filename)
+    with _TqdmUpTo(
+        unit="B",
+        unit_scale=True,
+        unit_divisor=1024,
+        miniters=1,
+        desc="dic.tar.gz",
+    ) as t:  # all optional kwargs
+        urlretrieve(_DICT_URL, filename, reporthook=t.update_to)
+        t.total = t.n
     print("Extracting tar file {}".format(filename))
     with tarfile.open(filename, mode="r|gz") as f:
         f.extractall(path=pkg_resources.resource_filename(__name__, ""))
     OPEN_JTALK_DICT_DIR = pkg_resources.resource_filename(
         __name__, "open_jtalk_dic_utf_8-1.11"
-    ).encode("ascii")
+    ).encode("utf-8")
     os.remove(filename)
 
 
